<?php declare(strict_types=1);

namespace Infomaker\Imengine\Helpers;

/**
 * Class ImengineHelper
 *
 * @package Infomaker\Imengine\Helpers
 */
class ImengineHelper
{
    /**
     *
     * @param int    $width
     * @param string $ratio
     *
     * @return int
     */
    public static function calculateRatioHeight(int $width, string $ratio): int
    {
        [$ratio_width, $ratio_height] = explode(':', $ratio);

        return (int)round(($width / (int)$ratio_width) * (int)$ratio_height);
    }

    /**
     * Calculate the new values in percentage to the original with maximum sizing
     *
     * @param $originalWidth
     * @param $originalHeight
     * @param $ratio
     *
     * @return array
     */
    public static function calculateCropValues(int $originalWidth, int $originalHeight, string $ratio): array
    {
        [$ratioWidth, $ratioHeight] = explode(':', $ratio);
        $originalRatio = $originalWidth / $originalHeight;
        $newRatio      = $ratioWidth / $ratioHeight;

        if ($originalRatio > $newRatio) {
            $new_height = $originalHeight;
            $new_width  = $new_height * $newRatio;

            $diffHeight = $new_height / $originalHeight;
            $diffWidth  = $new_width / $originalWidth;

        } else {
            $new_width  = $originalWidth;
            $new_height = $new_width / $newRatio;

            $diffHeight = $new_height / $originalHeight;
            $diffWidth  = $new_width / $originalWidth;
        }

        return [
            $diffWidth,
            $diffHeight,
        ];
    }
}
